# CHANGELOG

## 0.3.2 (2022-05-23)

### Fix

- minor feat, add bucket cors set and get, plus restructure tests

## 0.3.1 (2022-05-19)

### Fix

- move get_url to utils, add favicon to s3 static website

## 0.3.0 (2022-05-19)

### Feat

- add s3 bucket functions to list directories

## 0.2.1 (2022-05-18)

### Fix

- cases where env vars are set after bucket class import

## 0.2.0 (2022-05-17)

### Feat

- add static website config funcs, fix existing funcs
- add s3 bucket class and api helper functions

## 0.1.0 (2022-05-16)

### Feat

- REDACTED
